import 'package:reactive_forms_annotations/reactive_forms_annotations.dart';

part 'forms.gform.dart';

Map<String, dynamic>? requiredValidator(AbstractControl<dynamic> control) {
  return Validators.required(control);
}

@ReactiveFormAnnotation()
class CreateProject {
  final String doi;
  final String? label;
  final String? notes;

  final List<String>? datasetIds;

  CreateProject(
      {@FormControlAnnotation(validators: [requiredValidator]) this.doi = '',
      @FormControlAnnotation() this.label,
      @FormControlAnnotation() this.notes,
      @FormControlAnnotation() this.datasetIds});
}

@ReactiveFormAnnotation()
class CreateDataset {
  final String? label;
  final String? notes;

  final Animal? animal;
  final List<TargetedMutation> targetedMutation;
  final MicroscopyMethod? microscopyMethod;
  final BrainStructure? brainStructure;

  CreateDataset(
      {@FormControlAnnotation() this.label,
      @FormControlAnnotation() this.notes,
      this.animal,
      @FormArrayAnnotation() this.targetedMutation = const [], // note diff
      this.microscopyMethod,
      @FormControlAnnotation() this.brainStructure});
}

@FormGroupAnnotation()
class Animal {
  final String species;

  Animal({@FormControlAnnotation(validators: [requiredValidator]) this.species = ''});
}

@FormGroupAnnotation()
class TargetedMutation {
  final String gene;
  final bool isKnockOut;
  final String method;

  TargetedMutation(
      {@FormControlAnnotation(validators: [requiredValidator]) this.gene = '',
      @FormControlAnnotation() this.isKnockOut = false,
      @FormControlAnnotation(validators: [requiredValidator]) this.method = ''});
}

@FormGroupAnnotation()
class MicroscopyMethod {
  final String name;

  MicroscopyMethod({@FormControlAnnotation(validators: [requiredValidator]) this.name = ''});
}

class BrainStructure {
  final String name;

  BrainStructure({@FormControlAnnotation(validators: [requiredValidator]) this.name = ''});
}
